@@ -4,7 +4,7 @@ from paypal.payflow import models
 
 
 class TxnAdmin(admin.ModelAdmin):
-    list_display = ['pnref', 'amount', 'get_trxtype_display',
+    list_display = ['pnref', 'comment1', 'amount', 'get_trxtype_display',
                     'get_tender_display', 'result', 'respmsg', 'date_created']
 
     readonly_fields = [
@@ -14,6 +14,9 @@ class TxnAdmin(admin.ModelAdmin):
         'pnref',
         'ppref',
         'cvv2match',
+        'comment1',
+        'avsaddr',
+        'avszip',
         'result',
         'respmsg',
         'authcode',
